pub struct Font { /* private fields */ }Implementations
Sourceimpl Font
impl Font
pub fn line_height(&self) -> f32
pub fn ascender(&self) -> f32
pub fn descender(&self) -> f32
pub fn space_width(&self) -> f32
pub fn texture_size(&self) -> Point2
pub fn calculate_text_size(&self, text: &str) -> Vector2
Sourcepub fn create_baked_text_raw(
&self,
text: &str,
format: FontBakeFormat,
) -> Result<(Vec<u8>, u32, u32), String>
pub fn create_baked_text_raw( &self, text: &str, format: FontBakeFormat, ) -> Result<(Vec<u8>, u32, u32), String>
Bakes the text into a texture data buffer.
This is useful for rendering static text without needing to render each glyph individually.
Sourcepub fn save_font_cache(&self, path: &str) -> Result<(), Error>
pub fn save_font_cache(&self, path: &str) -> Result<(), Error>
Saves the font cache to a file.
This will create a binary file that can be loaded later using FontManager::load_font_cached.
Sourcepub fn get_image_data(&self) -> (Vec<u8>, u32, u32)
pub fn get_image_data(&self) -> (Vec<u8>, u32, u32)
Returns the image data of the font texture atlas.
Sourcepub fn get_glyph(&self, codepoint: u32) -> Result<Glyph, FontError>
pub fn get_glyph(&self, codepoint: u32) -> Result<Glyph, FontError>
Returns the font’s glyph for the given codepoint.
Sourcepub fn create_baked_text(
&self,
gpu: &mut GPU,
text: &str,
) -> Result<Texture, TextureError>
pub fn create_baked_text( &self, gpu: &mut GPU, text: &str, ) -> Result<Texture, TextureError>
Create a texture from the baked text.
This is useful for rendering static text without needing to render each glyph individually.
Examples found in repository?
examples/font.rs (line 25)
5fn main() {
6 let mut runner = est_render::runner::new().expect("Failed to create runner");
7
8 let mut window = runner
9 .create_window("Font Example", Point2::new(800, 600))
10 .build()
11 .expect("Failed to create window");
12
13 let mut gpu = est_render::gpu::new(Some(&mut window))
14 .build()
15 .expect("Failed to create GPU");
16
17 let mut font_manager = est_render::font::new();
18
19 let font = font_manager
20 .load_font("Arial", None, 20.0)
21 .expect("Failed to load font");
22
23 // Generate baked text texture
24 let texture = font
25 .create_baked_text(&mut gpu, "Hello, World!\nThis is a clear color example.")
26 .expect("Failed to create baked text");
27
28 while runner.pool_events(None) {
29 for event in runner.get_events() {
30 match event {
31 Event::WindowClosed { .. } => {
32 return;
33 }
34 _ => {}
35 }
36 }
37
38 if let Ok(mut cmd) = gpu.begin_command() {
39 if let Ok(mut gp) = cmd.begin_renderpass() {
40 gp.set_clear_color(Color::BLUE);
41
42 // The best texture blend for font rendering, others may has artifacts like black borders
43 gp.set_blend(0, Some(&BlendState::ADDITIVE_BLEND));
44
45 if let Some(mut drawing) = gp.begin_drawing() {
46 let size: Vector2 = texture.size().into();
47
48 // Baked text rendering
49 drawing.set_texture(Some(&texture));
50 drawing.draw_rect_image(Vector2::new(0.0, 0.0), size, Color::WHITE);
51
52 // Online text rendering
53 drawing.set_font(&font);
54 drawing.draw_text(
55 "Hello, World!\nThis is a clear color example.",
56 Vector2::new(size.x, 0.0),
57 Color::WHITE,
58 );
59 }
60 }
61 }
62 }
63}Sourcepub fn create_texture(&self, gpu: &mut GPU) -> Result<Texture, TextureError>
pub fn create_texture(&self, gpu: &mut GPU) -> Result<Texture, TextureError>
Creates a texture from the font’s glyph atlas.