Module runner

Runner for managing the main event loop and window lifecycle

Structs

Runner
Provide almost cross-platform event loop for the application.

Enums

CursorIcon
CustomCursorItem
DragAndDropEvent
Event
MouseScrollDelta
PollMode
RunnerError

Functions

new
Create a Runner instance, required for creating one or more windows.