pub enum DragAndDropEvent {
Dragleft,
DragEntered,
DragMoved,
DragDropped(Vec<String>),
}Variants
Dragleft
Occured when a drag enter the window.
DragEntered
Occured when a drag is moved over the window.
DragMoved
Occured when a drag is moved over the window.
DragDropped(Vec<String>)
Occured when a drag dropped on the window.