Event

Enum Event 

pub enum Event {
Show 13 variants WindowClosed { window_id: usize, }, WindowCreated { window_id: usize, parent_ref_id: Option<usize>, title: String, size: Point2, pos: Option<Point2>, }, WindowFocused { window_id: usize, focused: bool, }, WindowResized { window_id: usize, size: Point2, }, WindowMoved { window_id: usize, pos: Point2, }, CursorEntered { window_id: usize, }, CursorLeft { window_id: usize, }, CursorMoved { window_id: usize, pos: Point2, }, MouseWheel { window_id: usize, delta: MouseScrollDelta, }, MouseInput { window_id: usize, button: SmolStr, pressed: bool, }, RedrawRequested { window_id: usize, }, KeyboardInput { window_id: usize, key: SmolStr, pressed: bool, }, DragAndDrop { window_id: usize, event: DragAndDropEvent, },
}

Variants



WindowClosed

Happen when the window is closed, either by user action (such clicking X button on window) or programmatically.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.



WindowCreated

Happen when a new window is created.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

parent_ref_id: Option<usize>

The ID of the parent window, if any. will be None if the window is a top-level window.

This can be achived when creating a new window using the WindowBuilder::with_parent_window method.

title: String

The title of the window.

size: Point2

The size of the window in pixels.

pos: Option<Point2>

The position of the window in pixels, if specified.



WindowFocused

Happen when the window is focused or unfocused.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

focused: bool

Focused state of the window.



WindowResized

Happen when the window is resized.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

size: Point2

The new size of the window in pixels.



WindowMoved

Happen when the window is moved.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

pos: Point2

The new position of the window in pixels.



CursorEntered

Happen when the cursor enters the window.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.



CursorLeft

Happen when the cursor leaves the window.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.



CursorMoved

Happen when the cursor is moved within the window.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

pos: Point2

The new position of the cursor in pixels.



MouseWheel

Happen when the mouse wheel is scrolled.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

delta: MouseScrollDelta

The delta of the mouse wheel scroll.



MouseInput

Happen when a mouse button is pressed or released.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

button: SmolStr

The button that was pressed or released.

Either “Left”, “Right”, “Middle”, “Back”, or “Forward”.

pressed: bool

Whether the button was pressed or released.



RedrawRequested

Happen when the window requests a redraw.

Can be manually invoked by calling Window::request_redraw method.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.



KeyboardInput

Happen when a keyboard key is pressed or released.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

key: SmolStr

The key that was pressed or released.

The key string can be modifier keys like “Alt”, “Control”, “Shift”, etc. Which where the cases like a can be A.

pressed: bool

Whether the key was pressed or released.



DragAndDrop

Happen when a drag and drop event occurs in the window.

Fields

window_id: usize

The ID of the window that was closed, which can be used to identify the window in the application.

The window ID can be obtained from the Window instance using the Window::id method.

event: DragAndDropEvent

The drag and drop event that occurred.