pub enum PollMode {
Poll,
Wait,
WaitDraw,
}Variants
Poll
The event loop will poll for events and return immediately.
Wait
The event loop will wait for events and return when an event is available.
WaitDraw
The event loop will wait for events and return when the window needs to be redrawn. Unless calling the [Window::request_redraw] method.