Module software

Software rendering utilities Implementation of the software renderer using softbuffer crate.

This module provides a software renderer that can be used for rendering graphics without relying on a GPU. Does not provided any high-level abstractions such drawing quad or image, but rather low-level access to the softbuffer crate.
Provided as it, without any guarantees of performance or correctness.

Structs

PixelBuffer
A wrapper around softbuffer to provide a soft buffer for pixel manipulation
PixelBufferBuilder

Enums

PixelBlendMode
PixelBufferBuilderError
PixelBufferError
PixelWriteMode

Functions

new
Creates a new [software::PixelBuffer] instance.
This is not thread-safe and must be called from the same thread as the window.

Type Aliases

SoftbufferContext
SoftbufferSurface