Struct ArcRW

pub struct ArcRW<T> { /* private fields */ }

Implementations

Source

impl<T> ArcRW<T>

pub fn new(value: T) -> ArcRW<T>

Create a new ArcRW with the given value.

pub fn clone(&self) -> ArcRW<T>

Clone the ArcRW, incrementing the reference count.

pub fn try_read(&self) -> Option<RwLockReadGuard<'_, T>>

Try to borrow the value immutably.

pub fn try_write(&self) -> Option<RwLockWriteGuard<'_, T>>

Try to borrow the value mutably.

pub fn read(&self) -> RwLockReadGuard<'_, T>

Borrow the value immutably.

pub fn write(&self) -> RwLockWriteGuard<'_, T>

Borrow the value mutably.

pub fn wait_read(&self) -> RwLockReadGuard<'_, T>

Wait for the read lock to be available, blocking until it can be acquired. In debug mode, this will panic if the read lock is not acquired within 5 seconds.

pub fn wait_write(&self) -> RwLockWriteGuard<'_, T>

Wait for the write lock to be available, blocking until it can be acquired. In debug mode, this will panic if the write lock is not acquired within 5 seconds.

pub fn into_inner(self) -> Result<T, Self>

Try to unwrap the ArcRW, returning the inner value if there are no other references. If there are other references, return an ArcRW with the inner value.