Struct ArcRef

pub struct ArcRef<T> { /* private fields */ }
Custom ArcRef type that wraps a Arc with RefCell without Making it difficult to type.

Implementations

Source

impl<T> ArcRef<T>

pub fn new(value: T) -> ArcRef<T>

Create a new ArcRef with the given value.

pub fn clone(&self) -> ArcRef<T>

Creata a clone of the ArcRef. This will atomically increment the reference count.

pub fn wait_borrow(&self) -> Ref<'_, T>

Borrow the value immutably. This will atomically increment the reference count. If the value is already borrowed mutably, this will block until the mutable borrow is released. NOTE: In debug mode, this will panic if the value is already borrowed immutably for more than 5 seconds.

pub fn wait_borrow_mut(&self) -> RefMut<'_, T>

Borrow the value mutably. This will atomically increment the reference count. If the value is already borrowed, this will block until the borrow is released. NOTE: In debug mode, this will panic if the value is already borrowed mutably for more than 5 seconds.

pub fn borrow(&self) -> Ref<'_, T>

Try to borrow the value immutably. This will atomically increment the reference count. Will panic if the value is already borrowed mutably.

pub fn borrow_mut(&self) -> RefMut<'_, T>

Try to borrow the value mutably. This will atomically increment the reference count. Will panic if the value is already borrowed.

pub fn try_borrow(&self) -> Option<Ref<'_, T>>

Try to borrow the value immutably. This will atomically increment the reference count. Will return None if the value is already borrowed mutably.

pub fn try_borrow_mut(&self) -> Option<RefMut<'_, T>>

Try to borrow the value mutably. This will atomically increment the reference count. Will return None if the value is already borrowed.

pub fn try_unwrap(self) -> Result<T, Self>

Try to unwrap the ArcRef. This will return the inner value if there are no other references to it. If there are other references, this will return the ArcRef itself as an error.

pub fn ptr_eq(&self, other: &Self) -> bool

pub fn as_ptr(_self: &Self) -> *const T