pub struct FontManager { /* private fields */ }Implementations
Sourceimpl FontManager
impl FontManager
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new FontManager instance.
This will search for system fonts and cache them. It will also initialize an empty cache for loaded fonts.
Sourcepub fn load_font(
&mut self,
font_name: &str,
glyph_range: Option<&[(u32, u32)]>,
size: f32,
) -> Option<Font>
pub fn load_font( &mut self, font_name: &str, glyph_range: Option<&[(u32, u32)]>, size: f32, ) -> Option<Font>
Loads a font by name and size, optionally specifying a glyph range.
If the font is already cached, it will return the cached version.
If the font is not found, it will return None.
Examples found in repository?
examples/font.rs (line 20)
5fn main() {
6 let mut runner = est_render::runner::new().expect("Failed to create runner");
7
8 let mut window = runner
9 .create_window("Font Example", Point2::new(800, 600))
10 .build()
11 .expect("Failed to create window");
12
13 let mut gpu = est_render::gpu::new(Some(&mut window))
14 .build()
15 .expect("Failed to create GPU");
16
17 let mut font_manager = est_render::font::new();
18
19 let font = font_manager
20 .load_font("Arial", None, 20.0)
21 .expect("Failed to load font");
22
23 // Generate baked text texture
24 let texture = font
25 .create_baked_text(&mut gpu, "Hello, World!\nThis is a clear color example.")
26 .expect("Failed to create baked text");
27
28 while runner.pool_events(None) {
29 for event in runner.get_events() {
30 match event {
31 Event::WindowClosed { .. } => {
32 return;
33 }
34 _ => {}
35 }
36 }
37
38 if let Ok(mut cmd) = gpu.begin_command() {
39 if let Ok(mut gp) = cmd.begin_renderpass() {
40 gp.set_clear_color(Color::BLUE);
41
42 // The best texture blend for font rendering, others may has artifacts like black borders
43 gp.set_blend(0, Some(&BlendState::ADDITIVE_BLEND));
44
45 if let Some(mut drawing) = gp.begin_drawing() {
46 let size: Vector2 = texture.size().into();
47
48 // Baked text rendering
49 drawing.set_texture(Some(&texture));
50 drawing.draw_rect_image(Vector2::new(0.0, 0.0), size, Color::WHITE);
51
52 // Online text rendering
53 drawing.set_font(&font);
54 drawing.draw_text(
55 "Hello, World!\nThis is a clear color example.",
56 Vector2::new(size.x, 0.0),
57 Color::WHITE,
58 );
59 }
60 }
61 }
62 }
63}Sourcepub fn load_font_cached(&mut self, path: &str) -> Option<Font>
pub fn load_font_cached(&mut self, path: &str) -> Option<Font>
Loads a font from a cached file.
This will load the font from a binary file created by Font::save_font_cache. If the font is already cached, it will return the cached version.