pub struct Buffer { /* private fields */ }Expand description
Represents a GPU buffer.
Implementations
Sourceimpl Buffer
impl Buffer
pub fn usage(&self) -> BufferUsage
pub fn size(&self) -> u64
Sourcepub fn resize(&mut self, size: u64) -> Result<(), BufferError>
pub fn resize(&mut self, size: u64) -> Result<(), BufferError>
Resizes the buffer to the specified size.
Due to the nature of GPU buffers, this will create a new buffer and copy the existing data into it IF: \
- The old buffer has usage [BufferUsages::COPY_SRC] and [BufferUsages::MAP_READ].
Otherwise, it will simply resize the buffer without copying the data.
Sourcepub fn write_cmd(&self, src: &Buffer, encoder: &mut CommandBuffer)
pub fn write_cmd(&self, src: &Buffer, encoder: &mut CommandBuffer)
Writes the contents of the source buffer to this buffer using a command buffer.
This function is useful for when you want to write to the buffer in a command buffer context, such as during a render pass.
CommandBuffer::write_buffer is a more convenient way to write a buffer in a command buffer context.
Sourcepub fn write_raw<T: Pod + Zeroable>(&self, data: &[T])
pub fn write_raw<T: Pod + Zeroable>(&self, data: &[T])
Writes raw data to the buffer.
By default, this will create an intermediate buffer to copy the data into, and then write that buffer to the destination buffer. This function also will automatically pad the data to the required alignment if necessary.
Will panic if the buffer is not writable or if the data is larger than the buffer size.
Sourcepub fn write_raw_cmd<T: Pod + Zeroable>(
&self,
data: &[T],
encoder: &mut CommandBuffer,
)
pub fn write_raw_cmd<T: Pod + Zeroable>( &self, data: &[T], encoder: &mut CommandBuffer, )
Writes raw data to the buffer using a command buffer, useful for writing data during a render pass.
This function is useful for when you want to write to the buffer in a command buffer context, such as during a render pass. This function also will automatically pad the data to the required alignment if necessary.
CommandBuffer::write_buffer_raw is a more convenient way to write raw data to a buffer in a command buffer context.
Will panic if the buffer is not writable or if the data is larger than the buffer size.
Sourcepub fn read<T: Pod + Zeroable>(&self) -> Result<Vec<T>, BufferError>
pub fn read<T: Pod + Zeroable>(&self) -> Result<Vec<T>, BufferError>
Reads the buffer data into a vector of type T.
Unless if the buffer was created with [BufferUsages::COPY_SRC] or [BufferUsages::MAP_READ], this will create an intermediate buffer to copy the data into, and then read from that buffer.
pub fn map(&mut self, mode: BufferMapMode) -> Result<&mut Vec<u8>, BufferError>
pub fn unmap(&mut self)