pub struct SurfaceTexture { /* private fields */ }Expand description
Represents a texture handle that is used for rendering to the surface (swapchain).
This texture is created by the GPU and is used to present the rendered content to the screen. Can be used with the CommandBuffer to render to the surface.
Implementations
Sourceimpl SurfaceTexture
impl SurfaceTexture
pub fn get_view(&self) -> TextureView
pub fn get_size(&self) -> Extent3d
pub fn get_format(&self) -> TextureFormat
pub fn is_valid(&self) -> bool
pub fn is_suboptimal(&self) -> bool
pub fn present(&mut self)