pub struct ArcRW<T> { /* private fields */ }Implementations
Sourceimpl<T> ArcRW<T>
impl<T> ArcRW<T>
Sourcepub fn try_read(&self) -> Option<RwLockReadGuard<'_, T>>
pub fn try_read(&self) -> Option<RwLockReadGuard<'_, T>>
Try to borrow the value immutably.
Sourcepub fn try_write(&self) -> Option<RwLockWriteGuard<'_, T>>
pub fn try_write(&self) -> Option<RwLockWriteGuard<'_, T>>
Try to borrow the value mutably.
Sourcepub fn read(&self) -> RwLockReadGuard<'_, T>
pub fn read(&self) -> RwLockReadGuard<'_, T>
Borrow the value immutably.
Sourcepub fn write(&self) -> RwLockWriteGuard<'_, T>
pub fn write(&self) -> RwLockWriteGuard<'_, T>
Borrow the value mutably.
Sourcepub fn wait_read(&self) -> RwLockReadGuard<'_, T>
pub fn wait_read(&self) -> RwLockReadGuard<'_, T>
Wait for the read lock to be available, blocking until it can be acquired. In debug mode, this will panic if the read lock is not acquired within 5 seconds.
Sourcepub fn wait_write(&self) -> RwLockWriteGuard<'_, T>
pub fn wait_write(&self) -> RwLockWriteGuard<'_, T>
Wait for the write lock to be available, blocking until it can be acquired. In debug mode, this will panic if the write lock is not acquired within 5 seconds.
Sourcepub fn into_inner(self) -> Result<T, Self>
pub fn into_inner(self) -> Result<T, Self>
Try to unwrap the ArcRW, returning the inner value if there are no other references. If there are other references, return an ArcRW with the inner value.