pub struct ArcRef<T> { /* private fields */ }Expand description
Custom ArcRef type that wraps a Arc with RefCell without Making it difficult to type.
Implementations
Sourceimpl<T> ArcRef<T>
impl<T> ArcRef<T>
Sourcepub fn clone(&self) -> ArcRef<T>
pub fn clone(&self) -> ArcRef<T>
Creata a clone of the ArcRef. This will atomically increment the reference count.
Sourcepub fn wait_borrow(&self) -> Ref<'_, T>
pub fn wait_borrow(&self) -> Ref<'_, T>
Borrow the value immutably. This will atomically increment the reference count. If the value is already borrowed mutably, this will block until the mutable borrow is released. NOTE: In debug mode, this will panic if the value is already borrowed immutably for more than 5 seconds.
Sourcepub fn wait_borrow_mut(&self) -> RefMut<'_, T>
pub fn wait_borrow_mut(&self) -> RefMut<'_, T>
Borrow the value mutably. This will atomically increment the reference count. If the value is already borrowed, this will block until the borrow is released. NOTE: In debug mode, this will panic if the value is already borrowed mutably for more than 5 seconds.
Sourcepub fn borrow(&self) -> Ref<'_, T>
pub fn borrow(&self) -> Ref<'_, T>
Try to borrow the value immutably. This will atomically increment the reference count. Will panic if the value is already borrowed mutably.
Sourcepub fn borrow_mut(&self) -> RefMut<'_, T>
pub fn borrow_mut(&self) -> RefMut<'_, T>
Try to borrow the value mutably. This will atomically increment the reference count. Will panic if the value is already borrowed.
Sourcepub fn try_borrow(&self) -> Option<Ref<'_, T>>
pub fn try_borrow(&self) -> Option<Ref<'_, T>>
Try to borrow the value immutably. This will atomically increment the reference count. Will return None if the value is already borrowed mutably.
Sourcepub fn try_borrow_mut(&self) -> Option<RefMut<'_, T>>
pub fn try_borrow_mut(&self) -> Option<RefMut<'_, T>>
Try to borrow the value mutably. This will atomically increment the reference count. Will return None if the value is already borrowed.
Sourcepub fn try_unwrap(self) -> Result<T, Self>
pub fn try_unwrap(self) -> Result<T, Self>
Try to unwrap the ArcRef. This will return the inner value if there are no other references to it. If there are other references, this will return the ArcRef itself as an error.
pub fn ptr_eq(&self, other: &Self) -> bool
pub fn as_ptr(_self: &Self) -> *const T